:orphan:



.. _sphx_glr_auto_gallery:

Examples
========

Below is a gallery of examples.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A simple example of how to model a PDF using a crystal structure and a characteristic function.">

.. only:: html

 .. figure:: /auto_gallery/images/thumb/sphx_glr_plot_modeling_nickel_thumb.png
     :alt: Modeling of the PDF of Ni.

     :ref:`sphx_glr_auto_gallery_plot_modeling_nickel.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_gallery/plot_modeling_nickel
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download sphx-glr-download-python

    :download:`Download all examples in Python source code: auto_gallery_python.zip </auto_gallery/auto_gallery_python.zip>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

    :download:`Download all examples in Jupyter notebooks: auto_gallery_jupyter.zip </auto_gallery/auto_gallery_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
